@@ -34,11 +34,11 @@ class CircleCiProps:
     def __init__(
         self,
         *,
-        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[builtins.str, typing.Any]]]] = None,
         orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         setup: typing.Optional[builtins.bool] = None,
         version: typing.Optional[jsii.Number] = None,
-        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
+        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''(experimental) Options for class {@link Circleci}.
 
@@ -52,22 +52,13 @@ class CircleCiProps:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
-                orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                setup: typing.Optional[builtins.bool] = None,
-                version: typing.Optional[jsii.Number] = None,
-                workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__3c06d1b34693d265fea30a99659c5747190e9c57d57d9f113945e2e9c2869d82)
             check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
             check_type(argname="argument orbs", value=orbs, expected_type=type_hints["orbs"])
             check_type(argname="argument setup", value=setup, expected_type=type_hints["setup"])
             check_type(argname="argument version", value=version, expected_type=type_hints["version"])
             check_type(argname="argument workflows", value=workflows, expected_type=type_hints["workflows"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if jobs is not None:
             self._values["jobs"] = jobs
         if orbs is not None:
@@ -157,11 +148,11 @@ class Circleci(
         self,
         project: _Project_57d89203,
         *,
-        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[builtins.str, typing.Any]]]] = None,
         orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         setup: typing.Optional[builtins.bool] = None,
         version: typing.Optional[jsii.Number] = None,
-        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
+        workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[builtins.str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param project: -
@@ -174,17 +165,7 @@ class Circleci(
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                project: _Project_57d89203,
-                *,
-                jobs: typing.Optional[typing.Sequence[typing.Union["Job", typing.Dict[str, typing.Any]]]] = None,
-                orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                setup: typing.Optional[builtins.bool] = None,
-                version: typing.Optional[jsii.Number] = None,
-                workflows: typing.Optional[typing.Sequence[typing.Union["Workflow", typing.Dict[str, typing.Any]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__e2e6060b99c6fcc0051c7dac0012833613cc8aeda16307b7ed8accef2f464d02)
             check_type(argname="argument project", value=project, expected_type=type_hints["project"])
         options = CircleCiProps(
             jobs=jobs, orbs=orbs, setup=setup, version=version, workflows=workflows
@@ -204,9 +185,7 @@ class Circleci(
         :stability: experimental
         '''
         if __debug__:
-            def stub(name: builtins.str, orb: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__07fa7a0ae004a9efdf172ba4d70935adf896efa975017fefd5ecca96d1789b0a)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument orb", value=orb, expected_type=type_hints["orb"])
         return typing.cast(None, jsii.invoke(self, "addOrb", [name, orb]))
@@ -216,8 +195,8 @@ class Circleci(
         self,
         *,
         identifier: builtins.str,
-        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
-        triggers: typing.Optional[typing.Sequence[typing.Union["Triggers", typing.Dict[str, typing.Any]]]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[builtins.str, typing.Any]]]] = None,
+        triggers: typing.Optional[typing.Sequence[typing.Union["Triggers", typing.Dict[builtins.str, typing.Any]]]] = None,
         when: typing.Any = None,
     ) -> None:
         '''(experimental) add new workflow to existing pipeline.
@@ -287,19 +266,7 @@ class Docker:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                image: builtins.str,
-                auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                aws_auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                command: typing.Optional[typing.Sequence[builtins.str]] = None,
-                entrypoint: typing.Optional[typing.Sequence[builtins.str]] = None,
-                environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
-                name: typing.Optional[builtins.str] = None,
-                user: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__01002e199af73f14cb99914c29f5c88976ddb7c3567b6f98f72eab06613a1f6b)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
             check_type(argname="argument auth", value=auth, expected_type=type_hints["auth"])
             check_type(argname="argument aws_auth", value=aws_auth, expected_type=type_hints["aws_auth"])
@@ -308,7 +275,7 @@ class Docker:
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument user", value=user, expected_type=type_hints["user"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "image": image,
         }
         if auth is not None:
@@ -424,8 +391,8 @@ class Filter:
     def __init__(
         self,
         *,
-        branches: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
-        tags: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
+        branches: typing.Optional[typing.Union["FilterConfig", typing.Dict[builtins.str, typing.Any]]] = None,
+        tags: typing.Optional[typing.Union["FilterConfig", typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) The branches key controls whether the current branch should have a schedule trigger created for it, where current branch is the branch containing the config.yml file with the trigger stanza. That is, a push on the main branch will only schedule a workflow for the main branch.
 
@@ -449,16 +416,10 @@ class Filter:
         if isinstance(tags, dict):
             tags = FilterConfig(**tags)
         if __debug__:
-            def stub(
-                *,
-                branches: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
-                tags: typing.Optional[typing.Union["FilterConfig", typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6493d53ad3b6da8c4c026f0ee12c58a1016f759521f6f7ca4f504fb695302217)
             check_type(argname="argument branches", value=branches, expected_type=type_hints["branches"])
             check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if branches is not None:
             self._values["branches"] = branches
         if tags is not None:
@@ -513,16 +474,10 @@ class FilterConfig:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
-                only: typing.Optional[typing.Sequence[builtins.str]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__81f19b9f6bd71e5aa29ece449d79c7c236857bb54e3c624432e34d8cbc13904c)
             check_type(argname="argument ignore", value=ignore, expected_type=type_hints["ignore"])
             check_type(argname="argument only", value=only, expected_type=type_hints["only"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if ignore is not None:
             self._values["ignore"] = ignore
         if only is not None:
@@ -580,12 +535,12 @@ class Job:
         self,
         *,
         identifier: builtins.str,
-        docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[str, typing.Any]]]] = None,
+        docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[builtins.str, typing.Any]]]] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
-        machine: typing.Optional[typing.Union["Machine", typing.Dict[str, typing.Any]]] = None,
-        macos: typing.Optional[typing.Union["Macos", typing.Dict[str, typing.Any]]] = None,
+        machine: typing.Optional[typing.Union["Machine", typing.Dict[builtins.str, typing.Any]]] = None,
+        macos: typing.Optional[typing.Union["Macos", typing.Dict[builtins.str, typing.Any]]] = None,
         parallelism: typing.Optional[jsii.Number] = None,
-        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union["PipelineParameter", typing.Dict[str, typing.Any]]]] = None,
+        parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union["PipelineParameter", typing.Dict[builtins.str, typing.Any]]]] = None,
         resource_class: typing.Optional[builtins.str] = None,
         shell: typing.Optional[builtins.str] = None,
         steps: typing.Optional[typing.Sequence[typing.Any]] = None,
@@ -618,22 +573,7 @@ class Job:
         if isinstance(macos, dict):
             macos = Macos(**macos)
         if __debug__:
-            def stub(
-                *,
-                identifier: builtins.str,
-                docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[str, typing.Any]]]] = None,
-                environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
-                machine: typing.Optional[typing.Union["Machine", typing.Dict[str, typing.Any]]] = None,
-                macos: typing.Optional[typing.Union["Macos", typing.Dict[str, typing.Any]]] = None,
-                parallelism: typing.Optional[jsii.Number] = None,
-                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union["PipelineParameter", typing.Dict[str, typing.Any]]]] = None,
-                resource_class: typing.Optional[builtins.str] = None,
-                shell: typing.Optional[builtins.str] = None,
-                steps: typing.Optional[typing.Sequence[typing.Any]] = None,
-                working_directory: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__97531d78e2f2b3c8448832e412f0f67b6d3bebdd7fffb6c833ae2f02941f25ce)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument docker", value=docker, expected_type=type_hints["docker"])
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
@@ -645,7 +585,7 @@ class Job:
             check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
             check_type(argname="argument steps", value=steps, expected_type=type_hints["steps"])
             check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "identifier": identifier,
         }
         if docker is not None:
@@ -841,16 +781,10 @@ class Machine:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                image: builtins.str,
-                docker_layer_caching: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__53881feec4d48228721967bbc45502093f8e241f270887e7eb698227861f12c4)
             check_type(argname="argument image", value=image, expected_type=type_hints["image"])
             check_type(argname="argument docker_layer_caching", value=docker_layer_caching, expected_type=type_hints["docker_layer_caching"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "image": image,
         }
         if docker_layer_caching is not None:
@@ -908,11 +842,9 @@ class Macos:
         :stability: experimental
         '''
         if __debug__:
-            def stub(*, xcode: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ed4f40484bb7d08edd22d95fc5819356e6a1dc781d345e50bdc4e18b7d530987)
             check_type(argname="argument xcode", value=xcode, expected_type=type_hints["xcode"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "xcode": xcode,
         }
 
@@ -959,16 +891,10 @@ class Matrix:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                alias: typing.Optional[builtins.str] = None,
-                parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[typing.Sequence[builtins.str], typing.Sequence[jsii.Number]]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9fed56caa15ccb04aa2e24693becc1edac083f1a34e5f4a0e2caf8c3b5b21c79)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
             check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if alias is not None:
             self._values["alias"] = alias
         if parameters is not None:
@@ -1031,18 +957,11 @@ class PipelineParameter:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                type: "PipelineParameterType",
-                default: typing.Optional[typing.Union[builtins.str, jsii.Number, builtins.bool]] = None,
-                description: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__01127749913d95b4e7f45fa3bc48b191b3477ff11336e9b4e0f0ef6c16158a1e)
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
             check_type(argname="argument default", value=default, expected_type=type_hints["default"])
             check_type(argname="argument description", value=description, expected_type=type_hints["description"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "type": type,
         }
         if default is not None:
@@ -1203,19 +1122,7 @@ class Run:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                command: builtins.str,
-                background: typing.Optional[builtins.str] = None,
-                environment: typing.Optional[builtins.str] = None,
-                name: typing.Optional[builtins.str] = None,
-                no_output_timeout: typing.Optional[builtins.str] = None,
-                shell: typing.Optional[builtins.str] = None,
-                when: typing.Optional[builtins.str] = None,
-                working_directory: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__ef55a171334206583878dc9d13725a2a79510575ee335fad532dcbb2dabc37e9)
             check_type(argname="argument command", value=command, expected_type=type_hints["command"])
             check_type(argname="argument background", value=background, expected_type=type_hints["background"])
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
@@ -1224,7 +1131,7 @@ class Run:
             check_type(argname="argument shell", value=shell, expected_type=type_hints["shell"])
             check_type(argname="argument when", value=when, expected_type=type_hints["when"])
             check_type(argname="argument working_directory", value=working_directory, expected_type=type_hints["working_directory"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "command": command,
         }
         if background is not None:
@@ -1338,7 +1245,7 @@ class Schedule:
     def __init__(
         self,
         *,
-        filters: typing.Union[Filter, typing.Dict[str, typing.Any]],
+        filters: typing.Union[Filter, typing.Dict[builtins.str, typing.Any]],
         cron: typing.Optional[builtins.str] = None,
     ) -> None:
         '''(experimental) A workflow may have a schedule indicating it runs at a certain time.
@@ -1352,16 +1259,10 @@ class Schedule:
         if isinstance(filters, dict):
             filters = Filter(**filters)
         if __debug__:
-            def stub(
-                *,
-                filters: typing.Union[Filter, typing.Dict[str, typing.Any]],
-                cron: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__f1eb058b832a1f70afb2296b06a8c2f97e1b047e8cf0a4b94fe0ec43792c51c1)
             check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
             check_type(argname="argument cron", value=cron, expected_type=type_hints["cron"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "filters": filters,
         }
         if cron is not None:
@@ -1406,7 +1307,7 @@ class StepRun:
     def __init__(
         self,
         *,
-        run: typing.Optional[typing.Union[Run, typing.Dict[str, typing.Any]]] = None,
+        run: typing.Optional[typing.Union[Run, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Execution steps for Job.
 
@@ -1418,14 +1319,9 @@ class StepRun:
         if isinstance(run, dict):
             run = Run(**run)
         if __debug__:
-            def stub(
-                *,
-                run: typing.Optional[typing.Union[Run, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__efa1cf3a4b2feef1c889328d0e73fa8f62094d12b0e2dc6f22aae32c20fdfed0)
             check_type(argname="argument run", value=run, expected_type=type_hints["run"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if run is not None:
             self._values["run"] = run
 
@@ -1458,7 +1354,7 @@ class Triggers:
     def __init__(
         self,
         *,
-        schedule: typing.Optional[typing.Union[Schedule, typing.Dict[str, typing.Any]]] = None,
+        schedule: typing.Optional[typing.Union[Schedule, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''(experimental) Specifies which triggers will cause this workflow to be executed.
 
@@ -1472,14 +1368,9 @@ class Triggers:
         if isinstance(schedule, dict):
             schedule = Schedule(**schedule)
         if __debug__:
-            def stub(
-                *,
-                schedule: typing.Optional[typing.Union[Schedule, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__7918035c7d67628f34b078a926269a579082194ef7b6bc77cf819cf875a4a512)
             check_type(argname="argument schedule", value=schedule, expected_type=type_hints["schedule"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if schedule is not None:
             self._values["schedule"] = schedule
 
@@ -1518,8 +1409,8 @@ class Workflow:
         self,
         *,
         identifier: builtins.str,
-        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
-        triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[str, typing.Any]]]] = None,
+        jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[builtins.str, typing.Any]]]] = None,
+        triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[builtins.str, typing.Any]]]] = None,
         when: typing.Any = None,
     ) -> None:
         '''(experimental) Used for orchestrating all jobs.
@@ -1537,20 +1428,12 @@ class Workflow:
         :stability: experimental
         '''
         if __debug__:
-            def stub(
-                *,
-                identifier: builtins.str,
-                jobs: typing.Optional[typing.Sequence[typing.Union["WorkflowJob", typing.Dict[str, typing.Any]]]] = None,
-                triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[str, typing.Any]]]] = None,
-                when: typing.Any = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1c531c139b5afce396acd7a22ab9d3b6324b786877fd8f036d04a81cbb21f750)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument jobs", value=jobs, expected_type=type_hints["jobs"])
             check_type(argname="argument triggers", value=triggers, expected_type=type_hints["triggers"])
             check_type(argname="argument when", value=when, expected_type=type_hints["when"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "identifier": identifier,
         }
         if jobs is not None:
@@ -1630,8 +1513,8 @@ class WorkflowJob:
         *,
         identifier: builtins.str,
         context: typing.Optional[typing.Sequence[builtins.str]] = None,
-        filters: typing.Optional[typing.Union[Filter, typing.Dict[str, typing.Any]]] = None,
-        matrix: typing.Optional[typing.Union[Matrix, typing.Dict[str, typing.Any]]] = None,
+        filters: typing.Optional[typing.Union[Filter, typing.Dict[builtins.str, typing.Any]]] = None,
+        matrix: typing.Optional[typing.Union[Matrix, typing.Dict[builtins.str, typing.Any]]] = None,
         name: typing.Optional[builtins.str] = None,
         orb_parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
         requires: typing.Optional[typing.Sequence[builtins.str]] = None,
@@ -1658,19 +1541,7 @@ class WorkflowJob:
         if isinstance(matrix, dict):
             matrix = Matrix(**matrix)
         if __debug__:
-            def stub(
-                *,
-                identifier: builtins.str,
-                context: typing.Optional[typing.Sequence[builtins.str]] = None,
-                filters: typing.Optional[typing.Union[Filter, typing.Dict[str, typing.Any]]] = None,
-                matrix: typing.Optional[typing.Union[Matrix, typing.Dict[str, typing.Any]]] = None,
-                name: typing.Optional[builtins.str] = None,
-                orb_parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
-                requires: typing.Optional[typing.Sequence[builtins.str]] = None,
-                type: typing.Optional[JobType] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c171cfd438ea2ad47145a9a03f2eb8778481bbc92f3764eb6e7f7f614e76726a)
             check_type(argname="argument identifier", value=identifier, expected_type=type_hints["identifier"])
             check_type(argname="argument context", value=context, expected_type=type_hints["context"])
             check_type(argname="argument filters", value=filters, expected_type=type_hints["filters"])
@@ -1679,7 +1550,7 @@ class WorkflowJob:
             check_type(argname="argument orb_parameters", value=orb_parameters, expected_type=type_hints["orb_parameters"])
             check_type(argname="argument requires", value=requires, expected_type=type_hints["requires"])
             check_type(argname="argument type", value=type, expected_type=type_hints["type"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "identifier": identifier,
         }
         if context is not None:
@@ -1811,3 +1682,172 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3c06d1b34693d265fea30a99659c5747190e9c57d57d9f113945e2e9c2869d82(
+    *,
+    jobs: typing.Optional[typing.Sequence[typing.Union[Job, typing.Dict[builtins.str, typing.Any]]]] = None,
+    orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    setup: typing.Optional[builtins.bool] = None,
+    version: typing.Optional[jsii.Number] = None,
+    workflows: typing.Optional[typing.Sequence[typing.Union[Workflow, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e2e6060b99c6fcc0051c7dac0012833613cc8aeda16307b7ed8accef2f464d02(
+    project: _Project_57d89203,
+    *,
+    jobs: typing.Optional[typing.Sequence[typing.Union[Job, typing.Dict[builtins.str, typing.Any]]]] = None,
+    orbs: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    setup: typing.Optional[builtins.bool] = None,
+    version: typing.Optional[jsii.Number] = None,
+    workflows: typing.Optional[typing.Sequence[typing.Union[Workflow, typing.Dict[builtins.str, typing.Any]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__07fa7a0ae004a9efdf172ba4d70935adf896efa975017fefd5ecca96d1789b0a(
+    name: builtins.str,
+    orb: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__01002e199af73f14cb99914c29f5c88976ddb7c3567b6f98f72eab06613a1f6b(
+    *,
+    image: builtins.str,
+    auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    aws_auth: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    command: typing.Optional[typing.Sequence[builtins.str]] = None,
+    entrypoint: typing.Optional[typing.Sequence[builtins.str]] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+    name: typing.Optional[builtins.str] = None,
+    user: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6493d53ad3b6da8c4c026f0ee12c58a1016f759521f6f7ca4f504fb695302217(
+    *,
+    branches: typing.Optional[typing.Union[FilterConfig, typing.Dict[builtins.str, typing.Any]]] = None,
+    tags: typing.Optional[typing.Union[FilterConfig, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__81f19b9f6bd71e5aa29ece449d79c7c236857bb54e3c624432e34d8cbc13904c(
+    *,
+    ignore: typing.Optional[typing.Sequence[builtins.str]] = None,
+    only: typing.Optional[typing.Sequence[builtins.str]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__97531d78e2f2b3c8448832e412f0f67b6d3bebdd7fffb6c833ae2f02941f25ce(
+    *,
+    identifier: builtins.str,
+    docker: typing.Optional[typing.Sequence[typing.Union[Docker, typing.Dict[builtins.str, typing.Any]]]] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+    machine: typing.Optional[typing.Union[Machine, typing.Dict[builtins.str, typing.Any]]] = None,
+    macos: typing.Optional[typing.Union[Macos, typing.Dict[builtins.str, typing.Any]]] = None,
+    parallelism: typing.Optional[jsii.Number] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[PipelineParameter, typing.Dict[builtins.str, typing.Any]]]] = None,
+    resource_class: typing.Optional[builtins.str] = None,
+    shell: typing.Optional[builtins.str] = None,
+    steps: typing.Optional[typing.Sequence[typing.Any]] = None,
+    working_directory: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__53881feec4d48228721967bbc45502093f8e241f270887e7eb698227861f12c4(
+    *,
+    image: builtins.str,
+    docker_layer_caching: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ed4f40484bb7d08edd22d95fc5819356e6a1dc781d345e50bdc4e18b7d530987(
+    *,
+    xcode: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9fed56caa15ccb04aa2e24693becc1edac083f1a34e5f4a0e2caf8c3b5b21c79(
+    *,
+    alias: typing.Optional[builtins.str] = None,
+    parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[typing.Sequence[builtins.str], typing.Sequence[jsii.Number]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__01127749913d95b4e7f45fa3bc48b191b3477ff11336e9b4e0f0ef6c16158a1e(
+    *,
+    type: PipelineParameterType,
+    default: typing.Optional[typing.Union[builtins.str, jsii.Number, builtins.bool]] = None,
+    description: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ef55a171334206583878dc9d13725a2a79510575ee335fad532dcbb2dabc37e9(
+    *,
+    command: builtins.str,
+    background: typing.Optional[builtins.str] = None,
+    environment: typing.Optional[builtins.str] = None,
+    name: typing.Optional[builtins.str] = None,
+    no_output_timeout: typing.Optional[builtins.str] = None,
+    shell: typing.Optional[builtins.str] = None,
+    when: typing.Optional[builtins.str] = None,
+    working_directory: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f1eb058b832a1f70afb2296b06a8c2f97e1b047e8cf0a4b94fe0ec43792c51c1(
+    *,
+    filters: typing.Union[Filter, typing.Dict[builtins.str, typing.Any]],
+    cron: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__efa1cf3a4b2feef1c889328d0e73fa8f62094d12b0e2dc6f22aae32c20fdfed0(
+    *,
+    run: typing.Optional[typing.Union[Run, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7918035c7d67628f34b078a926269a579082194ef7b6bc77cf819cf875a4a512(
+    *,
+    schedule: typing.Optional[typing.Union[Schedule, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__1c531c139b5afce396acd7a22ab9d3b6324b786877fd8f036d04a81cbb21f750(
+    *,
+    identifier: builtins.str,
+    jobs: typing.Optional[typing.Sequence[typing.Union[WorkflowJob, typing.Dict[builtins.str, typing.Any]]]] = None,
+    triggers: typing.Optional[typing.Sequence[typing.Union[Triggers, typing.Dict[builtins.str, typing.Any]]]] = None,
+    when: typing.Any = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c171cfd438ea2ad47145a9a03f2eb8778481bbc92f3764eb6e7f7f614e76726a(
+    *,
+    identifier: builtins.str,
+    context: typing.Optional[typing.Sequence[builtins.str]] = None,
+    filters: typing.Optional[typing.Union[Filter, typing.Dict[builtins.str, typing.Any]]] = None,
+    matrix: typing.Optional[typing.Union[Matrix, typing.Dict[builtins.str, typing.Any]]] = None,
+    name: typing.Optional[builtins.str] = None,
+    orb_parameters: typing.Optional[typing.Mapping[builtins.str, typing.Union[builtins.str, jsii.Number, builtins.bool]]] = None,
+    requires: typing.Optional[typing.Sequence[builtins.str]] = None,
+    type: typing.Optional[JobType] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
